import 'package:zego_plugin_adapter/src/beauty/zego_beauty_plugin_enums.dart';

import 'package:zego_plugin_adapter/src/beauty/zego_beauty_plugin_inner_text.dart';
import 'package:zego_plugin_adapter/src/beauty/zego_beauty_plugin_ui_config.dart';

/// @nodoc
class ZegoBeautyPluginConfig {
  late List<ZegoBeautyPluginEffectsType> effectsTypes;

  late ZegoBeautyPluginInnerText innerText;

  late ZegoBeautyPluginUIConfig uiConfig;

  // backgroundPortraitSegmentation feature need use this path.
  String? segmentationBackgroundImageName;

  // if true, can use getFaceDetection to notify face detection.
  bool enableFaceDetection = false;

  ZegoBeautyPluginConfig({
    List<ZegoBeautyPluginEffectsType>? effectsTypes,
    ZegoBeautyPluginInnerText? innerText,
    ZegoBeautyPluginUIConfig? uiConfig,
    this.segmentationBackgroundImageName,
    this.enableFaceDetection = false,
  }) {
    this.effectsTypes = effectsTypes ?? allEffectsTypes();
    this.innerText = innerText ?? ZegoBeautyPluginInnerText();
    this.uiConfig = uiConfig ?? ZegoBeautyPluginUIConfig();
  }

  // default effects types.
  // https://www.zegocloud.com/pricing/product-list#ai-effects

  static List<ZegoBeautyPluginEffectsType> beautifyEffectsTypes(
      {bool enableBasic = true,
      bool enableAdvanced = true,
      bool enableMakeup = true,
      bool enableStyle = true}) {
    var types = <ZegoBeautyPluginEffectsType>[];
    if (enableBasic) {
      types += ZegoBeautyPluginEffectsType.values.sublist(
          ZegoBeautyPluginEffectsType.beautyBasicSmoothing.index,
          ZegoBeautyPluginEffectsType.beautyBasicDarkCircles.index + 1);
    }

    if (enableAdvanced) {
      types += ZegoBeautyPluginEffectsType.values.sublist(
          ZegoBeautyPluginEffectsType.beautyAdvancedFaceSlimming.index,
          ZegoBeautyPluginEffectsType.beautyAdvancedForeheadSlimming.index + 1);
    }

    if (enableMakeup) {
      types += ZegoBeautyPluginEffectsType.values.sublist(
          ZegoBeautyPluginEffectsType.beautyMakeupLipstickCameoPink.index,
          ZegoBeautyPluginEffectsType
                  .beautyMakeupColoredContactsChocolateBrown.index +
              1);
    }

    if (enableStyle) {
      types += ZegoBeautyPluginEffectsType.values.sublist(
          ZegoBeautyPluginEffectsType.beautyStyleMakeupInnocentEyes.index,
          ZegoBeautyPluginEffectsType.beautyStyleMakeupFlawless.index + 1);
    }

    return types;
  }

  static List<ZegoBeautyPluginEffectsType> filterEffectsTypes() =>
      ZegoBeautyPluginEffectsType.values.sublist(
          ZegoBeautyPluginEffectsType.filterNaturalCreamy.index,
          ZegoBeautyPluginEffectsType.filterDreamySweet.index + 1);

  static List<ZegoBeautyPluginEffectsType> stickersEffectsTypes() =>
      ZegoBeautyPluginEffectsType.values.sublist(
          ZegoBeautyPluginEffectsType.stickerAnimal.index,
          ZegoBeautyPluginEffectsType.stickerSailorMoon.index + 1);

  static List<ZegoBeautyPluginEffectsType> backgroundEffectsTypes() =>
      ZegoBeautyPluginEffectsType.values.sublist(
          ZegoBeautyPluginEffectsType.backgroundGreenScreenSegmentation.index,
          ZegoBeautyPluginEffectsType.backgroundGaussianBlur.index + 1);

  static List<ZegoBeautyPluginEffectsType> allEffectsTypes() {
    return List.from(ZegoBeautyPluginEffectsType.values)
      ..remove(ZegoBeautyPluginEffectsType.backgroundGreenScreenSegmentation);
  }
}
